searchData={"items":[{"type":"module","title":"TaskValidator","doc":"Validates TaskList.md format compliance according to project guidelines.\n\nThe `TaskValidator` ensures that task documents follow a consistent structure,\nmaking it easier to track and manage work across multiple project components,\nwith a strong focus on error handling practices.","ref":"TaskValidator.html"},{"type":"module","title":"Validation Checks - TaskValidator","doc":"* ID format compliance (like SSH0001, SCP0001, ERR001, etc.)\n* Unique task IDs across the document\n* Required sections and fields present in each task, including Error Handling Guidelines\n* Different error handling requirements for main tasks and subtasks:\n  - Main tasks: Comprehensive error handling documentation with GenServer-specific examples\n  - Subtasks: Simplified error handling focused on task-specific approaches\n* Proper subtask structure with consistent prefixes\n* Valid status values from the allowed list\n* Proper review rating format for completed tasks\n* Error handling patterns and conventions","ref":"TaskValidator.html#module-validation-checks"},{"type":"module","title":"Error Handling Requirements - TaskValidator","doc":"Main tasks must include comprehensive error handling sections:\n\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\nSubtasks have a simplified error handling format:\n\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"TaskValidator.html#module-error-handling-requirements"},{"type":"module","title":"Usage Example - TaskValidator","doc":"case TaskValidator.validate_file(\"path/to/TaskList.md\") do\n      {:ok, message} ->\n        # Task list validation succeeded\n        IO.puts(\"Validation passed: \" <> message)\n      {:error, reason} ->\n        # Task list validation failed\n        IO.puts(\"Validation failed: \" <> reason)\n    end","ref":"TaskValidator.html#module-usage-example"},{"type":"function","title":"TaskValidator.extract_references/1","doc":"Extracts reference definitions from the content.\nReference definitions are in the format:\n## \\{\\{reference-name\\}\\} or ## #\\{\\{reference-name\\}\\}\nContent for the reference\n...","ref":"TaskValidator.html#extract_references/1"},{"type":"function","title":"TaskValidator.extract_tasks/1","doc":"Extracts tasks from the TaskList.md content.","ref":"TaskValidator.html#extract_tasks/1"},{"type":"function","title":"TaskValidator.validate_file/1","doc":"Validates a TaskList.md file against the specified format requirements.\n\nReturns `:ok` if validation passes, or `{:error, reason}` if it fails.","ref":"TaskValidator.html#validate_file/1"},{"type":"function","title":"TaskValidator.validate_references/2","doc":"Validates that all {{ref-name}} placeholders in the content have corresponding definitions.\nDoes NOT expand references - only validates they exist.","ref":"TaskValidator.html#validate_references/2"},{"type":"task","title":"mix task_validator.create_template","doc":"Creates a template TaskList.md file with example tasks.\n\nThis task generates a new TaskList.md file with example tasks that follow\nthe required structure and format specifications. Use this as a starting\npoint for your own task list.","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html"},{"type":"task","title":"Usage - mix task_validator.create_template","doc":"mix task_validator.create_template [OPTIONS]","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-usage"},{"type":"task","title":"Options - mix task_validator.create_template","doc":"--path       Path where to create the TaskList.md file (default: ./TaskList.md)\n    --prefix     Project prefix for example tasks (default: PRJ)\n    --category   Task category to generate template for: core, features, documentation, testing (default: features)","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-options"},{"type":"task","title":"Example - mix task_validator.create_template","doc":"mix task_validator.create_template\n    mix task_validator.create_template --path ./docs/TaskList.md --prefix SSH --category core\n    mix task_validator.create_template --category documentation","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#module-example"},{"type":"function","title":"Mix.Tasks.TaskValidator.CreateTemplate.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.TaskValidator.CreateTemplate.html#run/1"},{"type":"task","title":"mix validate_tasklist","doc":"Validates the format and structure of a TaskList.md file.","ref":"Mix.Tasks.ValidateTasklist.html"},{"type":"task","title":"Task List Structure - mix validate_tasklist","doc":"The task list must contain two main sections:\n- Current Tasks (Active tasks in progress)\n- Completed Tasks (Tasks that have been finished)","ref":"Mix.Tasks.ValidateTasklist.html#module-task-list-structure"},{"type":"task","title":"Validation Rules - mix validate_tasklist","doc":"","ref":"Mix.Tasks.ValidateTasklist.html#module-validation-rules"},{"type":"task","title":"Task ID Format - mix validate_tasklist","doc":"- 2-4 uppercase letters as prefix (e.g., SSH, SCP, ERR)\n- 3-4 digits as sequence number\n- Optional hyphen and number for subtasks (e.g., SSH0001-1)\n- Examples: SSH0001, SCP0001, ERR001, SSH0001-1","ref":"Mix.Tasks.ValidateTasklist.html#module-task-id-format"},{"type":"task","title":"Status Values - mix validate_tasklist","doc":"Valid statuses:\n- Planned\n- In Progress\n- Review\n- Completed\n- Blocked","ref":"Mix.Tasks.ValidateTasklist.html#module-status-values"},{"type":"task","title":"Priority Values - mix validate_tasklist","doc":"Valid priorities:\n- Critical\n- High\n- Medium\n- Low","ref":"Mix.Tasks.ValidateTasklist.html#module-priority-values"},{"type":"task","title":"Error Handling Requirements - mix validate_tasklist","doc":"Main tasks and subtasks have different error handling requirements:\n\n#### Main Tasks\nMust include comprehensive error handling documentation:\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\n#### Subtasks\nUse simplified error handling format:\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"Mix.Tasks.ValidateTasklist.html#module-error-handling-requirements"},{"type":"task","title":"Common Validation Errors: - mix validate_tasklist","doc":"- Using wrong error handling format (e.g., main task format for subtasks)\n- Missing error handling sections\n- Incomplete error handling documentation","ref":"Mix.Tasks.ValidateTasklist.html#module-common-validation-errors"},{"type":"task","title":"Required Sections - mix validate_tasklist","doc":"Main tasks must include:\n- Description\n- Simplicity Progression Plan\n- Simplicity Principle\n- Abstraction Evaluation\n- Requirements\n- ExUnit Test Requirements\n- Integration Test Scenarios\n- Typespec Requirements\n- TypeSpec Documentation\n- TypeSpec Verification\n- Status\n- Priority","ref":"Mix.Tasks.ValidateTasklist.html#module-required-sections"},{"type":"task","title":"Subtask Requirements - mix validate_tasklist","doc":"- Must use same prefix as parent task\n- Must have \"Status\" section\n- If status is \"Completed\", must have \"Review Rating\"\n- Review rating format: 1-5 with optional decimal (e.g., 4.5)\n- Review rating can include \"(partial)\" suffix\n- Can be organized as checkboxes or numbered entries","ref":"Mix.Tasks.ValidateTasklist.html#module-subtask-requirements"},{"type":"task","title":"Subtask Formats - mix validate_tasklist","doc":"Tasks can organize subtasks in two formats:\n\n1. **Checkbox Format** (Recommended):\n```markdown\n**Subtasks**\n- [x] Basic structure implementation [SSH0001-1]\n- [ ] Essential features [SSH0001-2]\n- [ ] Integration testing [SSH0001-3]\n```\n\n2. **Numbered Format**:\n```markdown\n#### 1. Basic structure implementation (SSH0001-1)\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n```","ref":"Mix.Tasks.ValidateTasklist.html#module-subtask-formats"},{"type":"task","title":"Additional Rules - mix validate_tasklist","doc":"- Tasks marked as \"In Progress\" must have at least one subtask\n- All non-completed tasks must have detailed entries\n- No duplicate task IDs allowed\n- All subtasks must use the same prefix as their parent task","ref":"Mix.Tasks.ValidateTasklist.html#module-additional-rules"},{"type":"task","title":"Usage - mix validate_tasklist","doc":"mix validate_tasklist [OPTIONS]","ref":"Mix.Tasks.ValidateTasklist.html#module-usage"},{"type":"task","title":"Options - mix validate_tasklist","doc":"--path  Specify a non-default path to the TaskList.md file (default: docs/TaskList.md)","ref":"Mix.Tasks.ValidateTasklist.html#module-options"},{"type":"task","title":"Example - mix validate_tasklist","doc":"mix validate_tasklist\n    mix validate_tasklist --path ./custom/path/TaskList.md","ref":"Mix.Tasks.ValidateTasklist.html#module-example"},{"type":"function","title":"Mix.Tasks.ValidateTasklist.run/1","doc":"Callback implementation for  Mix.Task.run/1 .","ref":"Mix.Tasks.ValidateTasklist.html#run/1"},{"type":"extras","title":"TaskValidator","doc":"# TaskValidator\n\nA library for validating Markdown task lists against a structured format specification.","ref":"readme.html"},{"type":"extras","title":"Installation - TaskValidator","doc":"Add `task_validator` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:task_validator, \"~> 0.6.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - TaskValidator","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Command Line - TaskValidator","doc":"```bash\n# Validate the default TaskList.md file\nmix validate_tasklist\n\n# Validate a custom file path\nmix validate_tasklist --path ./path/to/custom/TaskList.md\n\n# Create a new task list template\nmix create_template\n\n# Create a template with custom prefix\nmix create_template --prefix SSH\n\n# Create a template for a specific category\nmix create_template --category features\nmix create_template --category documentation\n```","ref":"readme.html#command-line"},{"type":"extras","title":"Programmatic - TaskValidator","doc":"```elixir\ncase TaskValidator.validate_file(\"path/to/tasklist.md\") do\n  {:ok, message} ->\n    IO.puts(\"Success: #{message}\")\n  {:error, reason} ->\n    IO.puts(\"Error: #{reason}\")\nend\n```","ref":"readme.html#programmatic"},{"type":"extras","title":"Format Specification - TaskValidator","doc":"The TaskValidator enforces a specific format for task lists with a strong focus on error handling:\n\n- Task IDs must follow a consistent pattern: 2-4 uppercase letters followed by 3-4 digits (e.g., SSH0001, SCP0001, ERR001, REF0002)\n- Subtasks use numeric suffixes (SSH0001-1, SSH0001-2, etc.)\n- Checkbox format is recommended for subtasks: `- [x] Completed task [SSH0001-1]` or `- [ ] Pending task [SSH0001-2]`\n- Dependencies field tracks relationships between tasks\n- Code Quality KPIs enforce limits: max 5 functions/module, 15 lines/function, call depth 2\n- Task categories with specific number ranges:\n  * Core infrastructure: 1-99\n  * Features: 100-199\n  * Documentation: 200-299\n  * Testing: 300-399\n- Main tasks and subtasks have different error handling section requirements:\n  * Main tasks: Comprehensive error handling documentation including GenServer specifics\n  * Subtasks: Simplified error handling focused on task-specific approaches\n- Other required sections include Description, Status, Priority, Dependencies, etc.\n- Tasks marked as \"In Progress\" must have subtasks\n- Review ratings must follow the specified format (1-5 scale)\n- Support for reference definitions to reduce repetition (e.g., {{error-handling-main}})","ref":"readme.html#format-specification"},{"type":"extras","title":"Error Handling Requirements - TaskValidator","doc":"Main tasks must include the following comprehensive error handling sections:\n\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```\n\nSubtasks have a simplified error handling format:\n\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```","ref":"readme.html#error-handling-requirements"},{"type":"extras","title":"Dependencies - TaskValidator","doc":"Tasks can specify dependencies on other tasks using the Dependencies field:\n\n```markdown\n**Dependencies**\n- SSH0001 (Authentication must be complete)\n- ERR001 (Error handling framework required)\n```\n\nThe validator ensures all referenced tasks exist in the task list.","ref":"readme.html#dependencies"},{"type":"extras","title":"Subtask Formats - TaskValidator","doc":"Subtasks can be organized in two formats:\n\n**Checkbox Format (Recommended):**\n```markdown","ref":"readme.html#subtask-formats"},{"type":"extras","title":"SSH0001: SSH Session Initialization - TaskValidator","doc":"**Subtasks**\n- [x] Implement password authentication [SSH0001-1]\n- [ ] Add key-based authentication [SSH0001-2]\n- [ ] Implement host verification [SSH0001-3]\n```\n\nThis format provides immediate visual feedback on task progress and is the recommended approach for new task lists.\n\n**Numbered Format (Alternative):**\n```markdown\n#### 1. Implement password authentication (SSH0001-1)\n**Status**\nCompleted\n**Review Rating**\n4.5\n```\n\nBoth formats are valid and can be mixed within the same task list.","ref":"readme.html#ssh0001-ssh-session-initialization"},{"type":"extras","title":"Code Quality KPIs - TaskValidator","doc":"All tasks must include code quality metrics that adhere to these limits:\n- Maximum functions per module: 5\n- Maximum lines per function: 15\n- Maximum call depth: 2\n\n```markdown\n**Code Quality KPIs**\n- Functions per module: 3\n- Lines per function: 12\n- Call depth: 2\n```","ref":"readme.html#code-quality-kpis"},{"type":"extras","title":"Reference Definitions - TaskValidator","doc":"To reduce repetition in task lists, you can define reusable content blocks:\n\n```markdown","ref":"readme.html#reference-definitions"},{"type":"extras","title":"Reference Definitions - TaskValidator","doc":"","ref":"readme.html#reference-definitions-1"},{"type":"extras","title":"error-handling-main - TaskValidator","doc":"**Error Handling**\n**Core Principles**\n- Pass raw errors\n...","ref":"readme.html#error-handling-main"},{"type":"extras","title":"standard-kpis - TaskValidator","doc":"**Code Quality KPIs**\n- Functions per module: 3\n...\n```\n\nThen use them in tasks with `{{reference-name}}`:\n\n```markdown","ref":"readme.html#standard-kpis"},{"type":"extras","title":"SSH0001: Some task - TaskValidator","doc":"**Dependencies**\n- None\n\n{{standard-kpis}}\n\n{{error-handling-main}}\n\n**Status**: Planned\n```\n\nThis significantly reduces file size and maintains consistency across tasks.","ref":"readme.html#ssh0001-some-task"},{"type":"extras","title":"Task Categories - TaskValidator","doc":"Tasks are organized into categories based on their ID number:\n- **Core Infrastructure (1-99)**: Essential system components\n- **Features (100-199)**: User-facing functionality\n- **Documentation (200-299)**: Documentation tasks\n- **Testing (300-399)**: Test implementation\n\nEach category has specific required sections. For example, feature tasks require:\n- Feature Specification\n- User Impact\n- Integration Points\n\nDocumentation tasks require:\n- Documentation Scope\n- Target Audience\n- Related Documents","ref":"readme.html#task-categories"},{"type":"extras","title":"Multi-Project Support - TaskValidator","doc":"The task validator supports multiple project prefixes in the same task list. Each prefix typically represents a different component or subproject:\n\n```markdown","ref":"readme.html#multi-project-support"},{"type":"extras","title":"Current Tasks - TaskValidator","doc":"| ID      | Description          | Status      | Priority |\n| ------- | -------------------- | ----------- | -------- |\n| SSH0001 | SSH authentication   | In Progress | High     |\n| SCP0001 | File transfer module | Planned     | Medium   |\n| ERR001  | Error handling       | In Progress | High     |\n```\n\nThe validator ensures consistency within each task hierarchy, so a task with ID \"SSH0001\" must have subtasks with IDs like \"SSH0001-1\", \"SSH0001-2\", etc.","ref":"readme.html#current-tasks"},{"type":"extras","title":"Example Files - TaskValidator","doc":"The repository includes several example files in the `test/fixtures` directory:\n\n- `sample_tasklist.md` - A basic valid task list\n- `multi_prefix_tasklist.md` - A valid task list with multiple project prefixes\n- `prefix_mismatch.md` - Demonstrates prefix mismatch validation (subtask has different prefix than parent)\n- `invalid_rating.md` - Shows validation of review rating format\n- `invalid_mix_prefixes.md` - Contains various validation errors\n\nYou can test validation against these examples:\n\n```bash\nmix validate_tasklist --path test/fixtures/multi_prefix_tasklist.md  # Should pass\nmix validate_tasklist --path test/fixtures/prefix_mismatch.md        # Should fail\n```","ref":"readme.html#example-files"},{"type":"extras","title":"License - TaskValidator","doc":"MIT License\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.7.0 (2025-05-25) - Changelog","doc":"","ref":"changelog.html#v0-7-0-2025-05-25"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Changed subtask ID format from letter suffixes to numeric suffixes (e.g., `SSH0001a` → `SSH0001-1`)\n- Updated reference syntax from `{{reference-name}}` to `#{{reference-name}}` for better clarity","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Features - Changelog","doc":"- Added checkbox format as the recommended approach for subtasks\n  - `- [x] Completed subtask [TASK0001-1]`\n  - `- [ ] Pending subtask [TASK0001-2]`\n- Both checkbox and numbered formats are now supported, with checkbox being recommended","ref":"changelog.html#features"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Updated all templates to use the new numeric subtask ID format\n- Enhanced documentation to show both subtask formats with clear recommendations\n- Updated mix help output to display the new checkbox format examples\n- Improved consistency across all documentation files","ref":"changelog.html#enhancements"},{"type":"extras","title":"Documentation - Changelog","doc":"- Updated `guides/writing_compliant_tasks.md` with new subtask format examples\n- Enhanced README.md to show checkbox format as recommended\n- Added comprehensive subtask format examples to mix task help","ref":"changelog.html#documentation"},{"type":"extras","title":"v0.6.0 (2025-05-23) - Changelog","doc":"","ref":"changelog.html#v0-6-0-2025-05-23"},{"type":"extras","title":"Features - Changelog","doc":"- Added support for checkbox-style subtasks (e.g., `- [ ] Subtask a [SSH0001a]`)\n- Added Dependencies field validation with cross-reference checking\n- Added Code Quality KPIs validation (max functions per module: 5, max lines per function: 15, max call depth: 2)\n- Added task category validation with predefined ranges:\n  - Core infrastructure: 1-99\n  - Features: 100-199\n  - Documentation: 200-299\n  - Testing: 300-399\n- Added category-specific required sections for different task types\n- Enhanced template generator with `--category` option for category-specific templates\n- Added reference definitions support to reduce repetition in task lists\n  - Define reusable content blocks with `","ref":"changelog.html#features-1"},{"type":"extras","title":"Reference Definitions` - Changelog","doc":"- Use references in tasks with `{{reference-name}}` syntax\n  - Templates now use references for error handling and KPIs\n  - Significantly reduces task list file size","ref":"changelog.html#reference-definitions"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Improved task ID regex to support letter suffixes for checkbox subtasks\n- Enhanced validation to ensure dependencies reference existing tasks\n- Added comprehensive category validation rules\n- Updated templates to include new required fields and sections","ref":"changelog.html#enhancements-1"},{"type":"extras","title":"v0.5.0 (2025-05-19) - Changelog","doc":"","ref":"changelog.html#v0-5-0-2025-05-19"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"- Changed error handling requirements: main tasks and subtasks now have different formats\n- Main tasks require comprehensive error handling with GenServer specifics\n- Subtasks use simplified error handling focused on task-specific approaches","ref":"changelog.html#breaking-changes-1"},{"type":"extras","title":"Documentation - Changelog","doc":"- Updated all documentation to reflect different error handling requirements\n- Added clear examples showing main task vs subtask error handling formats\n- Fixed test fixtures and templates to follow the new error handling patterns","ref":"changelog.html#documentation-1"},{"type":"extras","title":"v0.4.1 (2025-05-18) - Changelog","doc":"","ref":"changelog.html#v0-4-1-2025-05-18"},{"type":"extras","title":"Features - Changelog","doc":"- Added validation for completed tasks requiring implementation notes, complexity assessment, and maintenance impact\n- Enhanced documentation with examples of required completion sections\n- Updated guides with examples of compliant task documentation","ref":"changelog.html#features-2"},{"type":"extras","title":"v0.4.0 (2025-05-18) - Changelog","doc":"","ref":"changelog.html#v0-4-0-2025-05-18"},{"type":"extras","title":"Features - Changelog","doc":"- Added `mix create_template` task for generating new task list templates\n- Added `mix validate_tasklist` task for validating task lists\n- Improved CLI interface with better error handling and user feedback","ref":"changelog.html#features-3"},{"type":"extras","title":"v0.3.0 (2024-05-29) - Changelog","doc":"","ref":"changelog.html#v0-3-0-2024-05-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Improved module documentation\n- Better HexDocs integration\n- Added more examples and guides","ref":"changelog.html#enhancements-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed formatting issues in the validator\n- Improved error messages for better clarity","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"v0.2.1 (2024-05-25) - Changelog","doc":"","ref":"changelog.html#v0-2-1-2024-05-25"},{"type":"extras","title":"Enhancements - Changelog","doc":"- Added support for multi-project prefixes\n- Improved validation for subtask prefixes","ref":"changelog.html#enhancements-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"- Fixed issue with partial review ratings","ref":"changelog.html#bug-fixes-1"},{"type":"extras","title":"v0.1.0 (2024-05-20) - Changelog","doc":"- Initial release\n- Basic task validation functionality\n- Command-line interface via mix task","ref":"changelog.html#v0-1-0-2024-05-20"},{"type":"extras","title":"Writing Compliant Task Lists","doc":"# Writing Compliant Task Lists\n\nThis guide explains how to create task lists that comply with the `TaskValidator` specifications.","ref":"writing_compliant_tasks.html"},{"type":"extras","title":"Task List Structure - Writing Compliant Task Lists","doc":"A compliant task list has two main sections:\n\n```markdown","ref":"writing_compliant_tasks.html#task-list-structure"},{"type":"extras","title":"Current Tasks - Writing Compliant Task Lists","doc":"| ID      | Description          | Status      | Priority |\n| ------- | -------------------- | ----------- | -------- |\n| SSH0001 | SSH authentication   | In Progress | High     |\n| SCP0001 | File transfer module | Planned     | Medium   |\n| ERR001  | Error handling       | In Progress | High     |","ref":"writing_compliant_tasks.html#current-tasks"},{"type":"extras","title":"Completed Tasks - Writing Compliant Task Lists","doc":"| ID      | Description    | Status    | Completed By | Review Rating |\n| ------- | -------------- | --------- | ------------ | ------------- |\n| SSH0002 | Key generation | Completed | @developer1  | 4.5           |\n```","ref":"writing_compliant_tasks.html#completed-tasks"},{"type":"extras","title":"Task ID Format - Writing Compliant Task Lists","doc":"Task IDs must follow this pattern:\n\n- 2-4 uppercase letters as a prefix (representing a component or module)\n- 3-4 digits as a sequential number\n- Optional suffix for subtasks:\n  - Numeric: `-1`, `-2` (e.g., SSH0001-1)\n  - Letter: `a`, `b`, `c` for checkbox style (e.g., SSH0001a)\n\nExamples:\n\n- `SSH0001` - Main task for SSH component\n- `SSH0001-1` - First subtask of SSH0001 (numeric style)\n- `SSH0001a` - First subtask of SSH0001 (checkbox style)\n- `ERR001` - Error handling task (3-digit IDs allowed)\n- `SCP0005` - File transfer task","ref":"writing_compliant_tasks.html#task-id-format"},{"type":"extras","title":"Task Categories - Writing Compliant Task Lists","doc":"Task numbers fall into specific categories:\n- **Core Infrastructure (1-99)**: Essential system components\n- **Features (100-199)**: User-facing functionality\n- **Documentation (200-299)**: Documentation tasks\n- **Testing (300-399)**: Test implementation\n\nEach category has specific required sections (see Category-Specific Requirements below).","ref":"writing_compliant_tasks.html#task-categories"},{"type":"extras","title":"Error Handling Requirements - Writing Compliant Task Lists","doc":"Main tasks and subtasks have different error handling documentation requirements.","ref":"writing_compliant_tasks.html#error-handling-requirements"},{"type":"extras","title":"Main Tasks Error Handling Format - Writing Compliant Task Lists","doc":"Main tasks must include comprehensive error handling sections that follow this format:\n\n```markdown\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n**GenServer Specifics**\n- Handle_call/3 error pattern\n- Terminate/2 proper usage\n- Process linking considerations\n```","ref":"writing_compliant_tasks.html#main-tasks-error-handling-format"},{"type":"extras","title":"Subtasks Error Handling Format - Writing Compliant Task Lists","doc":"Subtasks have a simplified error handling format:\n\n```markdown\n**Error Handling**\n**Task-Specific Approach**\n- Error pattern for this task\n**Error Reporting**\n- Monitoring approach\n```\n\nThese sections ensure consistent error handling practices across the project while providing appropriate level of detail for each task type. Tasks without proper error handling sections will fail validation.","ref":"writing_compliant_tasks.html#subtasks-error-handling-format"},{"type":"extras","title":"Detailed Task Entries - Writing Compliant Task Lists","doc":"Each task needs a detailed entry with the following format:\n\n```markdown","ref":"writing_compliant_tasks.html#detailed-task-entries"},{"type":"extras","title":"SSH0001: Implement SSH authentication module - Writing Compliant Task Lists","doc":"**Description**\nDevelop the SSH authentication module supporting key-based and password authentication.\n\n**Simplicity Progression Plan**\n\n1. Start with basic password auth\n2. Add key-based auth\n3. Refine error handling\n\n**Simplicity Principle**\nProgressive enhancement\n\n**Abstraction Evaluation**\nMedium - abstracts authentication but maintains clear interfaces\n\n**Requirements**\n\n- Support for password auth\n- Support for public key auth\n- Configurability of allowed auth methods\n\n**ExUnit Test Requirements**\n\n- Test both auth methods\n- Test failure scenarios\n- Mock SSH server for integration tests\n\n**Integration Test Scenarios**\n\n- Auth with valid/invalid password\n- Auth with valid/invalid key\n- Auth with disabled methods\n\n**Typespec Requirements**\n\n- Define types for credentials\n- Define auth result types\n\n**TypeSpec Documentation**\nAll types should be documented clearly\n\n**TypeSpec Verification**\nUse Dialyzer to verify type correctness\n\n**Status**\nIn Progress\n\n**Priority**\nHigh\n\n**Dependencies**\n- ERR001 (Error handling framework must be complete)\n- AUTH005 (Authentication interface design)\n\n**Code Quality KPIs**\n- Functions per module: 4\n- Lines per function: 12\n- Call depth: 2\n\n**Subtasks**\n- [x] Implement password authentication [SSH0001-1]\n- [ ] Add key-based authentication [SSH0001-2]  \n- [ ] Implement host verification [SSH0001-3]\n\n#### 1. Implement password authentication (SSH0001-1)\n\n**Description**\nInitial implementation of password-based authentication.\n\n**Error Handling**\n**Task-Specific Approach**\n- Handle invalid credentials with specific error tuples\n- Use clean separation for auth failures vs. connection failures\n**Error Reporting**\n- Log auth attempts with appropriate level (info/warn)\n- Track failed attempts for rate limiting\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n\n#### 2. Add key-based authentication (SSH0001-2)\n\n**Description**\nSupport for RSA and ED25519 keys with proper validation.\n\n**Error Handling**\n**Task-Specific Approach**\n- Return descriptive error for invalid key formats\n- Handle key verification timeout with custom error\n**Error Reporting**\n- Log key verification attempts\n- Report metrics on key type usage\n\n**Status**\nIn Progress\n```","ref":"writing_compliant_tasks.html#ssh0001-implement-ssh-authentication-module"},{"type":"extras","title":"Status Values - Writing Compliant Task Lists","doc":"Valid status values are:\n\n- `Planned`\n- `In Progress`\n- `Review`\n- `Completed`\n- `Blocked`","ref":"writing_compliant_tasks.html#status-values"},{"type":"extras","title":"Priority Values - Writing Compliant Task Lists","doc":"Valid priority values are:\n\n- `Critical`\n- `High`\n- `Medium`\n- `Low`","ref":"writing_compliant_tasks.html#priority-values"},{"type":"extras","title":"Review Ratings - Writing Compliant Task Lists","doc":"For completed tasks, include a review rating:\n\n- Scale of 1-5 with optional decimal (e.g., `4.5`)\n- Can include `(partial)` suffix for partially meeting requirements","ref":"writing_compliant_tasks.html#review-ratings"},{"type":"extras","title":"Required Sections for Completed Tasks - Writing Compliant Task Lists","doc":"When a task is marked as \"Completed\", it must include these additional sections:\n\n**Implementation Notes**\nDescribe the implementation approach and patterns used.\n\n**Complexity Assessment**\nAssess the final complexity level (High/Medium/Low) and explain why.\n\n**Maintenance Impact**\nEvaluate the maintenance burden and any special considerations.\n\nExample:\n```markdown\n**Implementation Notes**\nElegant indirection pattern using Registry for PID resolution\n\n**Complexity Assessment**\nLow - Used built-in Registry with minimal custom code\n\n**Maintenance Impact**\nLow - Self-contained solution with clear interface\n```","ref":"writing_compliant_tasks.html#required-sections-for-completed-tasks"},{"type":"extras","title":"Dependencies Field - Writing Compliant Task Lists","doc":"Tasks should specify their dependencies on other tasks:\n\n```markdown\n**Dependencies**\n- SSH0001 (Authentication must be complete)\n- ERR001 (Error handling framework required)\n- None (for tasks with no dependencies)\n```\n\nThe validator ensures all referenced task IDs exist in the task list.","ref":"writing_compliant_tasks.html#dependencies-field"},{"type":"extras","title":"Code Quality KPIs - Writing Compliant Task Lists","doc":"All tasks must include code quality metrics:\n\n```markdown\n**Code Quality KPIs**\n- Functions per module: 3\n- Lines per function: 10\n- Call depth: 2\n```\n\nThese metrics must adhere to the following limits:\n- Maximum functions per module: 5\n- Maximum lines per function: 15\n- Maximum call depth: 2","ref":"writing_compliant_tasks.html#code-quality-kpis"},{"type":"extras","title":"Subtask Formats - Writing Compliant Task Lists","doc":"","ref":"writing_compliant_tasks.html#subtask-formats"},{"type":"extras","title":"Checkbox Format (Recommended) - Writing Compliant Task Lists","doc":"The checkbox format provides better visual tracking of subtask progress:\n\n```markdown\n**Subtasks**\n- [x] Implement password authentication [SSH0001-1]\n- [ ] Add key-based authentication [SSH0001-2]\n- [ ] Implement host verification [SSH0001-3]\n```\n\nThis format:\n- Uses standard markdown checkboxes `- [x]` for completed, `- [ ]` for pending\n- Includes descriptive task names followed by task ID in brackets\n- Makes progress immediately visible in the rendered markdown","ref":"writing_compliant_tasks.html#checkbox-format-recommended"},{"type":"extras","title":"Numbered Format (Alternative) - Writing Compliant Task Lists","doc":"Subtasks can also be documented as numbered entries with full details:\n\n```markdown\n#### 1. Implement password authentication (SSH0001-1)\n\n**Description**\nInitial implementation of password-based authentication.\n\n**Error Handling**\n**Task-Specific Approach**\n- Handle invalid credentials with specific error tuples\n**Error Reporting**  \n- Log auth attempts with appropriate level\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n```\n\nNote: Both formats are valid. The checkbox format is recommended for better visual tracking.","ref":"writing_compliant_tasks.html#numbered-format-alternative"},{"type":"extras","title":"Category-Specific Requirements - Writing Compliant Task Lists","doc":"Different task categories require different sections:","ref":"writing_compliant_tasks.html#category-specific-requirements"},{"type":"extras","title":"Core Infrastructure Tasks (1-99) - Writing Compliant Task Lists","doc":"Required sections:\n- Architecture Decision\n- System Impact\n- Dependency Analysis","ref":"writing_compliant_tasks.html#core-infrastructure-tasks-1-99"},{"type":"extras","title":"Feature Tasks (100-199) - Writing Compliant Task Lists","doc":"Required sections:\n- Feature Specification\n- User Impact\n- Integration Points","ref":"writing_compliant_tasks.html#feature-tasks-100-199"},{"type":"extras","title":"Documentation Tasks (200-299) - Writing Compliant Task Lists","doc":"Required sections:\n- Documentation Scope\n- Target Audience\n- Related Documents","ref":"writing_compliant_tasks.html#documentation-tasks-200-299"},{"type":"extras","title":"Testing Tasks (300-399) - Writing Compliant Task Lists","doc":"Required sections:\n- Test Coverage\n- Test Categories\n- Performance Impact","ref":"writing_compliant_tasks.html#testing-tasks-300-399"},{"type":"extras","title":"Using Reference Definitions - Writing Compliant Task Lists","doc":"To reduce repetition and maintain consistency, use reference definitions for common sections:\n\n1. Define references at the end of your task list:\n```markdown","ref":"writing_compliant_tasks.html#using-reference-definitions"},{"type":"extras","title":"Reference Definitions - Writing Compliant Task Lists","doc":"","ref":"writing_compliant_tasks.html#reference-definitions"},{"type":"extras","title":"error-handling-main - Writing Compliant Task Lists","doc":"**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n...\n```\n\n2. Use references in tasks:\n```markdown","ref":"writing_compliant_tasks.html#error-handling-main"},{"type":"extras","title":"SSH0001: Some task - Writing Compliant Task Lists","doc":"**Description**\nTask description here\n\n{{error-handling-main}}\n\n**Status**: Planned\n```\n\nCommon reference definitions:\n- `{{error-handling-main}}` - Full error handling for main tasks\n- `{{error-handling-subtask}}` - Simplified error handling for subtasks\n- `{{standard-kpis}}` - Standard code quality KPIs","ref":"writing_compliant_tasks.html#ssh0001-some-task"},{"type":"extras","title":"Common Validation Errors - Writing Compliant Task Lists","doc":"1. **Missing error handling sections** - All tasks and subtasks must include complete error handling documentation\n2. **Incomplete error handling documentation** - All three error handling subsections (Core Principles, Implementation, Examples) are required\n3. **Missing detailed entries** - All non-completed tasks need detailed entries\n4. **Missing required sections** - Ensure all required sections are present\n5. **Missing completion details** - Completed tasks must include implementation notes, complexity assessment and maintenance impact\n6. **Inconsistent subtask prefixes** - Subtasks must use same prefix as parent\n7. **In Progress tasks without subtasks** - Any \"In Progress\" task needs subtasks\n8. **Invalid status values** - Must be one of the valid status values\n9. **Missing review ratings** - Completed subtasks need review ratings\n10. **Invalid dependencies** - Referenced task IDs must exist\n11. **KPI violations** - Code quality metrics exceed maximum limits\n12. **Invalid task category** - Task number doesn't match prefix category\n13. **Missing category-specific sections** - Required sections based on task category are missing","ref":"writing_compliant_tasks.html#common-validation-errors"},{"type":"extras","title":"Example Task List","doc":"# Example Task List\n\nThis is a complete example of a task list that passes all validation checks.\n\n```markdown\n# Project Tasks","ref":"sample_tasklist.html"},{"type":"extras","title":"Current Tasks - Example Task List","doc":"| ID      | Description                 | Status      | Priority |\n| ------- | --------------------------- | ----------- | -------- |\n| SSH0001 | Implement SSH auth module   | In Progress | High     |\n| SCP0001 | File transfer functionality | Planned     | Medium   |\n| ERR001  | Error handling and recovery | In Progress | High     |\n| DOC0001 | Documentation framework     | Review      | Medium   |","ref":"sample_tasklist.html#current-tasks"},{"type":"extras","title":"Completed Tasks - Example Task List","doc":"| ID      | Description            | Status    | Completed By | Review Rating |\n| ------- | ---------------------- | --------- | ------------ | ------------- |\n| SSH0002 | Key generation service | Completed | @developer1  | 4.5           |\n```\n| SYS0001 | System initialization  | Completed | @developer2  | 5             |\n\n---","ref":"sample_tasklist.html#completed-tasks"},{"type":"extras","title":"SSH0001: Implement SSH authentication module - Example Task List","doc":"**Description**\nDevelop the SSH authentication module supporting key-based and password authentication methods with appropriate fallbacks and security measures.\n\n**Simplicity Progression Plan**\n\n1. Begin with password authentication\n2. Add public key authentication\n3. Implement host verification\n4. Add support for auth methods negotiation\n\n**Simplicity Principle**\nProgressive enhancement with clear interfaces\n\n**Abstraction Evaluation**\nMedium - abstracts authentication mechanisms while maintaining clear and secure interfaces\n\n**Requirements**\n\n- Support for password authentication\n- Support for public key authentication\n- Configurability of allowed authentication methods\n- Secure storage of authentication data\n- Proper error handling for auth failures\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**ExUnit Test Requirements**\n\n- Test both authentication methods independently\n- Test fallback mechanisms\n- Test with invalid credentials\n- Mock SSH server for integration tests\n\n**Integration Test Scenarios**\n\n- Authentication with valid/invalid password\n- Authentication with valid/invalid key\n- Authentication with disabled methods\n- Fallback behavior when preferred auth fails\n\n**Typespec Requirements**\n\n- Define types for credentials (password and key-based)\n- Define authentication result types\n- Define configuration option types\n\n**TypeSpec Documentation**\nAll types should be clearly documented with examples\n\n**TypeSpec Verification**\nUse Dialyzer to verify type correctness and prevent runtime errors\n\n**Status**\nIn Progress\n\n**Priority**\nHigh\n\n**Subtasks**\n- [x] Implement password authentication [SSH0001-1]\n- [ ] Add key-based authentication [SSH0001-2]\n- [ ] Implement host verification [SSH0001-3]\n- [ ] Add support for auth methods negotiation [SSH0001-4]\n\n#### SSH0001-1: Implement password authentication\n\n**Description**\nImplement basic password authentication with encryption and rate limiting.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.5\n\n#### SSH0001-2: Add key-based authentication\n\n**Description**\nSupport for RSA and ED25519 keys with proper validation.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nIn Progress\n\n---","ref":"sample_tasklist.html#ssh0001-implement-ssh-authentication-module"},{"type":"extras","title":"SCP0001: File transfer functionality - Example Task List","doc":"**Description**\nCreate a secure file transfer mechanism built on the SSH transport layer.\n\n**Simplicity Progression Plan**\n\n1. Implement basic file uploads\n2. Add download functionality\n3. Add resume capabilities\n4. Add directory synchronization\n\n**Simplicity Principle**\nIncremental complexity with solid foundations\n\n**Abstraction Evaluation**\nMedium - abstracts file operations while providing clear progress indicators\n\n**Requirements**\n\n- Support for uploading files\n- Support for downloading files\n- Progress reporting\n- Error handling and recovery\n- Directory operations\n\n**ExUnit Test Requirements**\n\n- Test file upload/download\n- Test with various file sizes\n- Test error conditions\n- Test progress reporting\n\n**Integration Test Scenarios**\n\n- Upload/download of various file types\n- Handling of network interruptions\n- Performance with large files\n- Directory operations\n\n**Typespec Requirements**\n\n- Define types for file operations\n- Define progress reporting types\n- Define error types\n\n**TypeSpec Documentation**\nClear documentation of types with usage examples\n\n**TypeSpec Verification**\nStatic analysis to ensure type safety\n\n**Status**\nPlanned\n\n**Priority**\nMedium\n\n**Subtasks**\n- [ ] Implement basic file uploads [SCP0001-1]\n- [ ] Add download functionality [SCP0001-2]\n- [ ] Add resume capabilities [SCP0001-3]\n- [ ] Add directory synchronization [SCP0001-4]\n\n---","ref":"sample_tasklist.html#scp0001-file-transfer-functionality"},{"type":"extras","title":"ERR001: Error handling and recovery - Example Task List","doc":"**Description**\nDevelop a comprehensive error handling system for the application.\n\n**Simplicity Progression Plan**\n\n1. Define error taxonomy\n2. Implement basic error handlers\n3. Add recovery mechanisms\n4. Integrate with logging\n\n**Simplicity Principle**\nStructured error handling with clear recovery paths\n\n**Abstraction Evaluation**\nHigh - centralizes error management while allowing specific handling\n\n**Requirements**\n\n- Consistent error types\n- Recovery mechanisms\n- Proper logging\n- User-friendly error messages\n\n**ExUnit Test Requirements**\n\n- Test error generation\n- Test recovery mechanisms\n- Test logging integration\n\n**Integration Test Scenarios**\n\n- Error propagation across modules\n- Recovery from various error conditions\n- Logging consistency\n\n**Typespec Requirements**\n\n- Define error type hierarchy\n- Define recovery mechanism types\n\n**TypeSpec Documentation**\nThorough documentation of error types and recovery options\n\n**TypeSpec Verification**\nVerify proper error handling through static analysis\n\n**Status**\nIn Progress\n\n**Priority**\nHigh\n\n**Subtasks**\n- [x] Define error taxonomy [ERR001-1]\n- [ ] Implement basic error handlers [ERR001-2]\n- [ ] Add recovery mechanisms [ERR001-3]\n- [ ] Integrate with logging [ERR001-4]\n\n#### ERR001-1: Define error taxonomy\n\n**Description**\nCreate a comprehensive classification of errors in the system.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.8\n\n#### ERR001-2: Implement basic error handlers\n\n**Description**\nCreate handlers for common error scenarios.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nIn Progress\n\n---","ref":"sample_tasklist.html#err001-error-handling-and-recovery"},{"type":"extras","title":"DOC0001: Documentation framework - Example Task List","doc":"**Description**\nCreate a documentation generation system for the project.\n\n**Simplicity Progression Plan**\n\n1. Set up basic documentation structure\n2. Add API documentation\n3. Add tutorials and examples\n4. Implement search functionality\n\n**Simplicity Principle**\nProgressive detail with consistent structure\n\n**Abstraction Evaluation**\nMedium - provides a standard framework while allowing flexibility\n\n**Requirements**\n\n- Support for code documentation\n- Support for tutorials\n- Searchable content\n- Version tracking\n\n**ExUnit Test Requirements**\n\n- Test documentation generation\n- Test cross-referencing\n- Test search functionality\n\n**Integration Test Scenarios**\n\n- Documentation generation from codebase\n- Search functionality testing\n- Version comparison\n\n**Typespec Requirements**\n\n- Define documentation structure types\n- Define search index types\n\n**TypeSpec Documentation**\nClear documentation of the documentation system itself\n\n**TypeSpec Verification**\nEnsure type consistency in documentation tools\n\n**Status**\nReview\n\n**Priority**\nMedium\n\n**Subtasks**\n- [x] Set up basic documentation structure [DOC0001-1]\n- [x] Add API documentation [DOC0001-2]\n- [x] Add tutorials and examples [DOC0001-3]\n- [ ] Implement search functionality [DOC0001-4]\n\n#### DOC0001-1: Set up basic documentation structure\n\n**Description**\nCreate the foundational structure for project documentation.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nCompleted\n\n**Review Rating**\n5\n\n#### DOC0001-2: Add API documentation\n\n**Description**\nGenerate comprehensive API documentation from code comments.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.3\n\n#### DOC0001-3: Add tutorials and examples\n\n**Description**\nCreate usage tutorials and example code.\n\n**Error Handling**\n**Core Principles**\n- Pass raw errors\n- Use {:ok, result} | {:error, reason}\n- Let it crash\n**Error Implementation**\n- No wrapping\n- Minimal rescue\n- function/1 & /! versions\n**Error Examples**\n- Raw error passthrough\n- Simple rescue case\n- Supervisor handling\n\n**Status**\nCompleted\n\n**Review Rating**\n4.7\n\n---","ref":"sample_tasklist.html#doc0001-documentation-framework"},{"type":"extras","title":"SSH0002: Key generation service - Example Task List","doc":"**Description**\nImplement secure key generation service supporting multiple algorithms.\n\n**Simplicity Progression Plan**\nProgressive implementation of key types\n\n**Simplicity Principle**\nMinimal interface with maximal security\n\n**Abstraction Evaluation**\nLow - Direct implementation of standard algorithms\n\n**Requirements**\n- Support RSA and ED25519 key generation\n- Secure key storage\n- Key format conversion utilities\n\n**ExUnit Test Requirements**\n- Test key generation for all supported types\n- Verify key formats and strength\n\n**Integration Test Scenarios**\n- Generate and verify keys\n- Test with SSH authentication module\n\n**Typespec Requirements**\n- Define key type specifications\n- Document all public interfaces\n\n**TypeSpec Documentation**\nClear documentation of key types and generation options\n\n**TypeSpec Verification**\nVerified with Dialyzer static analysis\n\n**Status**\nCompleted\n\n**Priority**\nHigh\n\n**Implementation Notes**\nElegant indirection pattern using Registry for PID resolution\n\n**Complexity Assessment**\nLow - Used built-in Registry with minimal custom code\n\n**Maintenance Impact**\nLow - Self-contained solution with clear interface\n\n**Review Rating**\n4.5","ref":"sample_tasklist.html#ssh0002-key-generation-service"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.1"}}